@@ -2,26 +2,69 @@
 A module for containing the endpoint logic of asymmetric.
 """
 
+from typing import Any, Callable, Dict, List, Optional
+
 from asymmetric.errors import DuplicatedEndpointError
 
 
+class Endpoint:
+
+    """
+    Class to encapsulate an endpoint.
+    """
+
+    def __init__(
+        self,
+        route: str,
+        method: str,
+        response_code: int,
+        function: Callable[..., Any],
+        decorated_function: Callable[..., Any],
+    ) -> None:
+        self.__route: str = route
+        self.__method: str = method
+        self.__response_code: int = response_code
+        self.__function: Callable[..., Any] = function
+        self.__decorated_function: Callable[..., Any] = decorated_function
+
+    @property
+    def route(self) -> str:
+        """Returns the route of the endpoint."""
+        return self.__route
+
+    @property
+    def method(self) -> str:
+        """Returns the HTTP method of the endpoint."""
+        return self.__method
+
+    @property
+    def response_code(self) -> int:
+        """Returns the response code of the endpoint."""
+        return self.__response_code
+
+    @property
+    def function(self) -> Callable[..., Any]:
+        """Returns the raw function of the endpoint."""
+        return self.__function
+
+
 class Endpoints:  # pylint: disable=R0903
 
     """
     Class to encapsulate the endpoints logic.
     """
 
-    def __init__(self):
-        self.__endpoints = {}
+    def __init__(self) -> None:
+        self.__endpoints: Dict[str, Dict[str, Endpoint]] = {}
 
     def add_endpoints(
-            self,
-            route,
-            methods,
-            response_code,
-            function,
-            decorated_function,
-    ):
+        self,
+        route: str,
+        methods: List[str],
+        response_code: int,
+        function: Callable[..., Any],
+        decorated_function: Callable[..., Any],
+    ) -> None:
         """
         Adds an endpoint for every method specified.
         """
@@ -35,13 +78,13 @@ class Endpoints:  # pylint: disable=R0903
             )
 
     def __add_endpoint(
-            self,
-            route,
-            method,
-            response_code,
-            function,
-            decorated_function,
-    ):
+        self,
+        route: str,
+        method: str,
+        response_code: int,
+        function: Callable[..., Any],
+        decorated_function: Callable[..., Any],
+    ) -> None:
         """
         Checks if the desired endpoint does not exist. If it exists,
         it raises an error. Otherwise, it creates the endpoint
@@ -60,11 +103,12 @@ class Endpoints:  # pylint: disable=R0903
             decorated_function,
         )
 
-        if self.__get_route(route) is None:
-            self.__create_route(route)
-        self.__get_route(route)[method] = endpoint
+        route_dictionary = self.__get_route(route)
+        if route_dictionary is None:
+            route_dictionary = self.__create_route(route)
+        route_dictionary[method] = endpoint
 
-    def __get_route(self, route):
+    def __get_route(self, route: str) -> Optional[Dict[str, Endpoint]]:
         """
         Returns the route dictionary containing each method
         as a key. If the route has not been used, returns None.
@@ -73,11 +117,12 @@ class Endpoints:  # pylint: disable=R0903
             return None
         return self.__endpoints[route]
 
-    def __create_route(self, route):
-        """Creates a route."""
+    def __create_route(self, route: str) -> Dict[str, Endpoint]:
+        """Creates a route and returns it."""
         self.__endpoints[route] = {}
+        return self.__endpoints[route]
 
-    def __get_endpoint(self, route, method):
+    def __get_endpoint(self, route: str, method: str) -> Optional[Endpoint]:
         """
         Returns the endpoint object for a specific route/method
         combination. If said combination does not exist, returns None.
@@ -88,44 +133,3 @@ class Endpoints:  # pylint: disable=R0903
         if method not in route_data:
             return None
         return route_data[method]
-
-
-class Endpoint:
-
-    """
-    Class to encapsulate an endpoint.
-    """
-
-    def __init__(
-            self,
-            route,
-            method,
-            response_code,
-            function,
-            decorated_function,
-    ):
-        self.__route = route
-        self.__method = method
-        self.__response_code = response_code
-        self.__function = function
-        self.__decorated_function = decorated_function
-
-    @property
-    def route(self):
-        """Returns the route of the endpoint."""
-        return self.__route
-
-    @property
-    def method(self):
-        """Returns the HTTP method of the endpoint."""
-        return self.__method
-
-    @property
-    def response_code(self):
-        """Returns the response code of the endpoint."""
-        return self.__response_code
-
-    @property
-    def function(self):
-        """Returns the raw function of the endpoint."""
-        return self.__function
